#
# spec file for package prboom-plus
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           prboom-plus
Version:        2.5.1.4
Release:        lp151.3.3.1
Summary:        Open source port of the DOOM game engine
License:        GPL-2.0+
Group:          Amusements/Games/3D/Shoot
Url:            http://prboom-plus.sf.net/

#SVN-Clone:	https://svn.prboom.org/repos/branches/prboom-plus-24/prboom2
#Sibling-Prj:	https://github.com/coelckers/prboom-plus (umapinfo fork)
#DL-URL:	http://downloads.sf.net/prboom-plus/prboom-plus-2.5.1.4.tar.gz
Source:         %name-%version+.tar.xz
Source2:        clean_source.sh
Patch1:         prboom-nodatetime.diff
Patch2:         prboom-types1.diff
Patch3:         prboom-types2.diff
Patch5:         prboom-enable-tessellation.diff
Patch6:         prboom-hbar-color.diff
Patch7:         prboom-hbar-all.diff
Patch8:         prboom-hbar-gradient.diff
Patch9:         0001-fix-heap-buffer-overflows-in-UDP-code-CVE-2019-20797.patch
BuildRequires:  Mesa-devel
BuildRequires:  automake
BuildRequires:  fluidsynth-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libSDL_image-devel
BuildRequires:  libSDL_mixer-devel
BuildRequires:  libSDL_net-devel
BuildRequires:  libpng-devel
BuildRequires:  libvorbis-devel
BuildRequires:  pcre-devel
%if 0%{?suse_version} >= 1320
BuildRequires:  portmidi-devel
%endif
BuildRequires:  update-desktop-files
Suggests:       freedoom
Provides:       prboom = 2.5.0plus
Obsoletes:      prboom <= 2.5.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PrBoom+ is a Doom source port developed from the original PrBoom
project, an open-source port of Doom, the classic 3D first-person
shooter game which outclassed any 3D world games that preceded
it, with amazing speed, flexibility, and outstanding gameplay.

prboom(-plus) focuses heavily on retaining compatibility with the
original Doom engines, which plays a big role in demo recording and
playback.

%prep
%setup -q
%patch -P 1 -P 2 -P 3 -P 5 -P 6 -P 7 -P 8 -P 9 -p1

%build
# rpm has its own optimizations, so turn off shipped defaults
%configure --enable-gl --disable-cpu-opt --program-prefix="" \
	--with-waddir="%_datadir/doom" --disable-dogs
make %{?_smp_mflags}

%install
%make_install gamesdir="%_bindir"

# convenience symlink
ln -s prboom-plus "%buildroot/%_bindir/prboom"

install -Dm0644 ICONS/prboom-plus.svg "%buildroot/%_datadir/icons/hicolor/scalable/apps/prboom-plus.svg"
install -Dm0644 ICONS/prboom-plus.desktop "%buildroot/%_datadir/applications/prboom-plus.desktop"

install -Dm0644 ICONS/prboom-plus.bash "%buildroot/%_datadir/bash-completion/completions/prboom-plus.bash"

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%_bindir/*
%_datadir/doom/
%_datadir/doc/%name-%version/
%_mandir/*/*
%_datadir/applications/prboom-plus.desktop
%_datadir/icons/hicolor/scalable/apps/prboom-plus.svg
%_datadir/bash-completion/

%changelog
* Tue Jun  9 2020 Jan Engelhardt <jengelh@inai.de>
- Add 0001-fix-heap-buffer-overflows-in-UDP-code-CVE-2019-20797.patch
  [CVE-2019-20797, boo#1171974]
* Tue Mar 29 2016 jengelh@inai.de
- Update to version 2.5.1.4
  * Added "Allow Jump" and "Allow Vertical Aiming" option on
  Prboom-plus 'bad' compatibility settings" page.
  * Added a "Backpack Changes Thresholds" option
  * "Use GL surface for software mode" mode now works much faster
  if gl_finish is 0 in config.
  * Better support for Chex Quest,
  * Fixed the classic "Long Wall" rendering error.
* Sun Mar 29 2015 jengelh@inai.de
- Avoid strange inequality in Provides tag
* Mon Nov 11 2013 jengelh@inai.de
- Update to snapshot 2.5.1.4 SVN4355
  * Added "Fix clipping problems in large levels" option.
  * Added "gl_finish" config variable.
  * Added a "Health Bar Above Monsters" option (health_bar* config
  variables; GL only).
  * Added a "Things appearance" automap option. Possible values:
  "classic", "scaled" and "icons".
  * Added "notarget" and "fly" cheat codes.
  * Added MBF's "-beta" codepointers.
  * Added a new HUD.
  * Added "shaders" sector light mode.
  * Support "Classic Doom" WAD files of Doom 3 BFG Edition and HACX
  1.2 IWAD
  * Restricted mouse look (Heretic-style Y-shearing) now is available
  in software mode.
  * Added a crosshair. Three different crosshair graphics are for
  choice: cross, angle and dot. Extra features are changing
  crosshair colors according to the player's health and/or on sight
  of a target.
  * "Use GL surface for software mode" mode now works much faster if
  gl_finish is 0 in config.
  * Ability to use e.g. doom1.wad as a resource for a doom2 IWAD,
  e.g. freedoom (prboom-plus -iwad freedoom.wad -file doom1.wad).
* Sun Mar 24 2013 jengelh@inai.de
- Update to new upstream release 2.5.1.3
  * Added device selection to portmidi player. Controlled by the
  snd_mididev config variable. See stdout.txt for list of
  available devices.
  * Added a progress bar for demo skipping during re-recording.
  * Added key binding options for start/stop and fast-forward when
  watching demos.
  * Added a key binding option to restart the current map.
  * Added a "Default compatibility level" GUI entry.
  * Support for 16 sprite rotations. http://zdoom.org/wiki/Sprite#Angles
  * New HUDs. HUDs definitions are moved to the
  "prboom-plus.wad/-prbhud-" lump.
- Remove prboom-protos.diff, merged upstream
* Fri May 25 2012 joop.boonen@opensuse.org
- Corrected typo in spec file
* Fri May 25 2012 joop.boonen@opensuse.org
- Added BuildRequires automake
* Wed Aug  3 2011 jengelh@medozas.de
- Enable missing USE_GLU_TESS for the self-referencing sector hack
  to be rendered.
* Mon Jun 20 2011 jengelh@medozas.de
- Update to new upstream release 2.5.1.1:
  * Support was added for sound fonts, OPL2 emulation, mouse wheel,
  changing resolution on the fly, interpolation of automap, and the
  "use GL surface for software mode" video option for the ability
  to use hardware vsync in software mode.
* Tue Nov 16 2010 jengelh@medozas.de
- Update to new upstream release 2.5.0.8a:
  * Support for textured automap was added. Compatibility with Doom
  1.2 was improved. New HUDs and bugs were fixed.
* Mon Aug 23 2010 jengelh@medozas.de
- Update to new upstream release 2.5.0.7:
  * A lot of compatibility and improvements, many bug fixes, and
  several new features were added, including support for DeePBSP and
  uncompressed ZDBSP nodes and dynamic music changing... through the
  new MUSINFO lump. On the GLBoom+ front, there is support for GZDoom
  skyboxes, custom detail texture definitions, and blending of
  animated flats and wall textures.
